<?php
/*
 * andwatch.inc
 *
 * part of pfSense (https://www.pfsense.org)
 * Copyright (c) 2025 Denny Page
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

require_once("config.inc");
require_once("functions.inc");
require_once("util.inc");
require_once("service-utils.inc");

function andwatch_query_interfaces($ifnames)
{
    $entries = array();

    foreach($ifnames as $ifname) {
        $real_ifname = get_real_interface($ifname);
        $friendly_ifname = convert_friendly_interface_to_friendly_descr($ifname);
    
        $pipe = popen("/usr/local/bin/andwatch-query $real_ifname", 'r');
        if ($pipe) {
            while ($line = fgets($pipe)) {
                list($date, $time, $age, $hostname, $ipaddr, $hwaddr, $org) = sscanf(trim($line), '%s %s %s %s %s %s %[^$]s');

                $entry = [
                    'ifdesc' => $friendly_ifname,
                    'datetime' => "$date $time",
                    'age' => $age,
                    'hostname' => $hostname,
                    'ipaddr' => $ipaddr,
                    'hwaddr' => $hwaddr,
                    'org' => $org
                ];
    
                $entries[] = $entry;
            }
            pclose($pipe);
        }
    }

    return $entries;
}

function andwatch_query_all()
{
    //$ifnames = array("lan");
    $ifnames = array("lan", "opt2", "opt3");

    return andwatch_query_interfaces($ifnames);
}

?>
